@@ -1,11 +1,15 @@
 package com.fasterxml.jackson.module.blackbird.deser;
 
+import org.junit.jupiter.api.Test;
+
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.module.blackbird.BlackbirdTestBase;
 
+import static org.junit.jupiter.api.Assertions.*;
+
 // [modules-base#141]
 public class DoublePrimitiveVarArgsSetterDeser141Test extends BlackbirdTestBase
 {
@@ -27,6 +31,7 @@ public class DoublePrimitiveVarArgsSetterDeser141Test extends BlackbirdTestBase
     private final ObjectMapper MAPPER = newObjectMapper();
 
     // [modules-base#141]
+    @Test
     public void testDoubleVarargsCreator() throws Exception
     {
         Foo141 foo = new Foo141().setBar(new double[] { 2.0, 0.25 });
